@@ -275,10 +275,16 @@ def fetch_crypto_hourly_data(ssj=None, local_root_directory=None, hourly_return_
         ts11 = ts10 - 2001 * 3600
         ts12 = ts11 - 2001 * 3600
         ts13 = ts12 - 2001 * 3600
+        ts14 = ts13 - 2001 * 3600
+        ts15 = ts14 - 2001 * 3600
+        ts16 = ts15 - 2001 * 3600
+        ts17 = ts16 - 2001 * 3600
+        ts18 = ts17 - 2001 * 3600
+
         print('Loading data')
         hours_url_request = 'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=' + ssj_against + '&e=' + exchange + '&toTs={}&limit=2000'
         dataframe = None
-        for me_timestamp in [ts13, ts12, ts11, ts10, ts9, ts8, ts7, ts6, ts5, ts4, ts3, ts2, ts1, ts]:
+        for me_timestamp in [ts18, ts17, ts16, ts15, ts14, ts13, ts12, ts11, ts10, ts9, ts8, ts7, ts6, ts5, ts4, ts3, ts2, ts1, ts]:
             print('waiting')
             df = request_hour_data_paquet(hours_url_request, me_timestamp, ssj)
             if df is not None:
