@@ -202,7 +202,7 @@ def flat_numba_drift_rebal(previous_weights, current_prices, previous_prices):
     new_weights = previous_weights*current_prices/previous_prices
     return new_weights
 
-#@njit()
+@njit()
 def numba_indice_rebalancing(early_rebal, rebal_data, price_data, previous_price_data, target_weights):
     values = np.zeros(price_data.shape[0])
     weights = np.zeros((price_data.shape[0],price_data.shape[1]))
@@ -212,9 +212,9 @@ def numba_indice_rebalancing(early_rebal, rebal_data, price_data, previous_price
             values[i] = np.sum(target_weights)
             continue
         must_rebalance = rebal_data[i]
-        if early_rebal:
-            drifted_weights = flat_numba_drift_rebal(weights[i - 1, :], price_data[i, :], previous_price_data[i, :])
-            must_rebalance = must_rebalance or np.sum(drifted_weights > target_weights)>0
+        if early_rebal and i >= 1:
+            previous_weights_have_drifted = np.sum(weights[i - 1, :] > target_weights) > 0
+            must_rebalance = must_rebalance or previous_weights_have_drifted
 
         if must_rebalance:
             weights[i, :] = values[i-1]*flat_numba_drift_rebal(target_weights, price_data[i,:], previous_price_data[i,:])
