@@ -15,6 +15,18 @@ class EodQuotePk:
         return self.productCode == other.productCode and self.date == other.date \
             if isinstance(other, self.__class__) else False
 
+    def __le__(self, other):
+        return self.date <= other.date
+
+    def __ge__(self, other):
+        return self.date >= other.date
+
+    def __lt__(self, other):
+        return self.date < other.date
+
+    def __gt__(self, other):
+        return self.date > other.date
+
 
 @dataclass
 class EodQuote:
@@ -44,3 +56,15 @@ class EodQuote:
             self.close = dict_object["close"]
             self.totalReturnClose = dict_object["totalReturnClose"]
             return self
+
+    def __le__(self, other):
+        return self.pk <= other.pk
+
+    def __ge__(self, other):
+        return self.pk >= other.pk
+
+    def __lt__(self, other):
+        return self.pk < other.pk
+
+    def __gt__(self, other):
+        return self.pk > other.pk
\ No newline at end of file
