@@ -625,7 +625,12 @@ def volume_slope_ls(data = None, contravariant = -1., up_trend_threshold=0.8, lo
 
 
     y = data[slope_column][-pente_window:].values
-    slope = stats.linregress(np.arange(pente_window), y).slope
+    slope = 0
+    try :
+        slope = stats.linregress(np.arange(pente_window), y).slope
+    except Exception as e :
+        print('investigate')
+        print(e)
 
     if trend_rank >= up_trend_threshold and slope>0 :
         return contravariant
@@ -674,7 +679,14 @@ def volume_slope_lo(data = None, contravariant = -1., up_trend_threshold=0.8, pe
 
 
     y = data[slope_column][-pente_window:].values
-    slope = stats.linregress(np.arange(pente_window), y).slope
+
+    slope = 0
+    try :
+        slope = stats.linregress(np.arange(pente_window), y).slope
+    except Exception as e :
+        print('investigate')
+        print(e)
+
 
     if trend_rank > up_trend_threshold and slope>0 :
         return contravariant
@@ -862,7 +874,14 @@ def slope_lo_induced(data = None, contravariant = -1., up_trend_threshold=0.8, p
 
 
     y = data[slope_column][-pente_window:].values
-    slope = stats.linregress(np.arange(pente_window), y).slope
+
+    slope = 0
+    try:
+        slope = stats.linregress(np.arange(pente_window), y).slope
+    except Exception as e:
+        print('investigate')
+        print(e)
+
 
     if trend_rank > up_trend_threshold and slope>0 :
         return contravariant
@@ -989,7 +1008,13 @@ def slope_ls(data = None, contravariant = -1., up_trend_threshold=0.8, low_trend
 
 
     y = data[slope_column][-pente_window:].values
-    slope = stats.linregress(np.arange(pente_window), y).slope
+
+    slope = 0
+    try :
+        slope = stats.linregress(np.arange(pente_window), y).slope
+    except Exception as e :
+        print('investigate')
+        print(e)
 
     if trend_rank >= up_trend_threshold and slope>0 :
         return contravariant
